 title  "asmFlashNada - PIC16F684 Flashing LED"
;
;  This Program Flashes the PICkit D0 LED between RA4 (Positive) 
;   and RA5 (negative) at approximately 2x per second without 
;   using any advanced control instructions.
;
;  Hardware Notes:
;   PIC16F684 running at 4 MHz Using the Internal Clock
;   Internal Reset is Used
;   RA4 - LED Positive
;   RA5 - LED Negative
;
;
;  Myke Predko
;  04.11.19

  LIST R=DEC
 INCLUDE "p16f684.inc"

 __CONFIG _FCMEN_OFF & _IESO_OFF & _BOD_OFF & _CPD_OFF & _CP_OFF & _MCLRE_ON & _PWRTE_ON & _WDT_OFF & _INTOSCIO

#DEFINE VBB_SIM 1	;The original code has been modified for better simulation speed
					;set VBB_SIM 0 when executing on real-hardware 

;  Variables
 CBLOCK 0x20
Dlay:2
 ENDC

  PAGE
;  Mainline

 org     0

  nop                           ;  For ICD Debug

  clrf    PORTA                 ;  Initialize I/O Bits to Off
  movlw   7                     ;  Turn off Comparators
  movwf   CMCON0
  movf    STATUS, w             ;  Set the RP0 Bit (Bit 5) to 
  iorlw   1 << 5                ;   Execute in Page 1
  movwf   STATUS
  clrf    ANSEL ^ 0x80          ;  All Bits are Digital
  movlw   b'001111'             ;  RA4/RA5 are Digital Outputs
  movwf   TRISA ^ 0x80
  movf    STATUS, w             ;  Clear RP0
  andlw   0xFF ^ (1 << 5)
  movwf   STATUS

Loop:                           ;  Return Here after D0 Toggle
  clrf    Dlay + 1              ;  High 8 Bits for Delay
  clrf    Dlay                  ;  Low 8 Bits for Delay

#if VBB_SIM 
	MOVLW .5					;  VBB doesn't simulate as fast as real hardware so
	MOVWF Dlay + 1				;  sometimes small changes in delay loops are used 
								;  to make the simulated circuit behave more closley
								;  to what it looks like on the real-circuit.
								;  In this example we reduce the loop delay count
#endif

DlayLoop:
  movlw   1                     ;  Decrement the Inside Loop
  subwf   Dlay, f
  movf    STATUS, w             ;  Zero Flag Set?  
  andlw   1 << 2                ;  Check Bit 2
  addwf   PCL, f                ;  Add to the Program Counter
  goto    DlayLoop              ;  Zero, Loop Around
  nop                           ;  Space Change in Address due
  nop                           ;   Zero Flag Being Set
  nop
  movlw   1                     ;  Decrement the Outside Loop
  subwf   Dlay + 1, f
  movf    STATUS, w             ;  Check for Zero
  andlw   1 << 2
  addwf   PCL, f
  goto    DlayLoop
  nop                           ;  Space Change in Address due
  nop                           ;   Zero Flag Being Set
  nop
  
  movlw   1 << 4                ;  Toggle RA4 (D0)
  xorwf   PORTA, f

  goto    Loop                  ;  Repeat


  end    
